Enum dashmap::try_result::TryResult [−][src]
pub enum TryResult<R> {
Present(R),
Absent,
Locked,
}Expand description
Represents the result of a non-blocking read from a DashMap.
Variants
Present(R)
The value was present in the map, and the lock for the shard was successfully obtained.
Absent
The shard wasn’t locked, and the value wasn’t present in the map.
Locked
The shard was locked.
Implementations
Returns true if the value was present in the map, and the lock for the shard was successfully obtained.
Returns true if the shard wasn’t locked, and the value wasn’t present in the map.